function P = khatrirao(A,B);
%KHATRIRAO Khatri-Rao product
%
%   KHATRIRAO(A,B) computes the Khatri-Rao product of matrices A and
%   B that have the same number of columns.  The result is the
%   column-wise Kronecker product
%   [KRON(B(:,1),A(:,1) ... KRON(B(:,n),A(:,n)]
%
%   Copyright 2005, Tamara Kolda and Brett Bader, Sandia National Labs
%
%   See also TENSOR.

%Brett W. Bader and Tamara G. Kolda, Released under SAND2004-5189,
%Sandia National Laboratories, 2004.  Please address questions or
%comments to: tgkolda@sandia.gov.  Terms of use: You are free to copy,
%distribute, display, and use this work, under the following
%conditions. (1) You must give the original authors credit. (2) You may
%not use or redistribute this work for commercial purposes. (3) You may
%not alter, transform, or build upon this work. (4) For any reuse or
%distribution, you must make clear to others the license terms of this
%work. (5) Any of these conditions can be waived if you get permission
%from the authors.


[ma,na] = size(A);
[mb,nb] = size(B);

if (na ~= nb)
  error('A and B must have the same number of columns.')
end

AB = zeros(ma*mb,na);
for n = 1:na
   ab = B(:,n) * A(:,n).';  % Compute outer product of nth columns
   P(:,n) = ab(:);          % Fill nth column of P with reshaped result
end

